@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 
 def format_code(source):
@@ -62,9 +62,25 @@ def starts_with_triple(string):
 
 
 def format_docstring(indentation, docstring):
-    """Return formatted version of docstring."""
+    """Return formatted version of docstring.
+
+    Relevant parts of PEP 257:
+    * For consistency, always use triple double quotes around docstrings.
+    * Triple quotes are used even though the string fits on one line.
+    * Multi-line docstrings consist of a summary line just like a one-line
+      docstring, followed by a blank line, followed by a more elaborate
+      description.
+    * The BDFL recommends inserting a blank line between the last paragraph
+      in a multi-line docstring and its closing quotes, placing the closing
+      quotes on a line by themselves.
+
+    """
     contents = strip_docstring(docstring)
 
+    # Skip if there are nested triple double quotes
+    if contents.count('"""'):
+        return docstring
+
     summary, description = split_summary_and_description(contents)
 
     if description:
@@ -129,7 +145,26 @@ def normalize_summary(summary):
     return summary
 
 
-def main(argv, output_file):
+def open_with_encoding(filename, encoding, mode='r'):
+    """Open file with a specific encoding."""
+    try:
+        # Python 3
+        return open(filename, mode=mode, encoding=encoding)
+    except TypeError:
+        return open(filename, mode=mode)
+
+
+def detect_encoding(filename):
+    """Return file encoding."""
+    try:
+        # Python 3
+        with open(filename, 'rb') as input_file:
+            return tokenize.detect_encoding(input_file.readline)[0]
+    except AttributeError:
+        return 'utf-8'
+
+
+def main(argv, standard_out):
     """Main entry point."""
     import argparse
     parser = argparse.ArgumentParser(description=__doc__)
@@ -144,22 +179,27 @@ def main(argv, output_file):
     args = parser.parse_args(argv)
 
     for filename in args.files:
-        with open(filename) as input_file:
+        encoding = detect_encoding(filename)
+        with open_with_encoding(filename, encoding=encoding) as input_file:
             source = input_file.read()
             formatted_source = format_code(source)
 
-        if args.in_place:
-            if args.backup:
-                with open(filename + '.backup', 'w') as backup_file:
-                    backup_file.write(source)
+        if source != formatted_source:
+            if args.in_place:
+                # Write output files with same encoding as input
+                if args.backup:
+                    with open_with_encoding(filename + '.backup', mode='w',
+                            encoding=encoding) as backup_file:
+                        backup_file.write(source)
 
-            with open(filename, 'w') as output_file:
-                output_file.write(formatted_source)
-        else:
-            import difflib
-            diff = difflib.unified_diff(
-                    source.splitlines(True),
-                    formatted_source.splitlines(True),
-                    'before/' + filename,
-                    'after/' + filename)
-            output_file.write(''.join(diff))
+                with open_with_encoding(filename, mode='w',
+                                        encoding=encoding) as output_file:
+                    output_file.write(formatted_source)
+            else:
+                import difflib
+                diff = difflib.unified_diff(
+                        source.splitlines(True),
+                        formatted_source.splitlines(True),
+                        'before/' + filename,
+                        'after/' + filename)
+                standard_out.write(''.join(diff))
